@@ -15,12 +15,16 @@ import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_s3._jsii
+import aws_cdk.aws_s3_assets._jsii
 import aws_cdk.core._jsii
 import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab-runner", "1.76.9", __name__[0:-6], "cdk-gitlab-runner@1.76.9.jsii.tgz"
+    "cdk-gitlab-runner",
+    "1.76.10",
+    __name__[0:-6],
+    "cdk-gitlab-runner@1.76.10.jsii.tgz",
 )
 
 __all__ = [
